==> hoteldruid_2.1.0.orig.tar.gz: hoteldruid/includes/templates/frasi_mod_disp.php <==
<?php

##################################################################################
#    HOTELDRUID
#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    any later version accepted by Marco Maria Francesco De Santis, which
#    shall act as a proxy as defined in Section 14 of version 3 of the
#    license.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
##################################################################################




$fr_frase = "";
$frase = "";

$fr_frase[0] = "fr_in";
$fr_frase[1] = "fr_Non_c_e_piu_disponibilita";
$fr_frase[2] = "fr_Controlla_la_disponibilita";
$fr_frase[3] = "fr_dal";
$fr_frase[4] = "fr_al";
$fr_frase[5] = "fr_per_la_tipologia";
$fr_frase[6] = "fr_tariffa";
$fr_frase[7] = "fr_Numero_di";
$fr_frase[8] = "fr_Aggiungi_una_nuova_tipologia";
$fr_frase[9] = "fr_Elimina_questa_tipologia";
$fr_frase[10] = "fr_per";
$fr_frase[11] = "fr_Data_di_arrivo";
$fr_frase[12] = "fr_Data_di_partenza";
$fr_frase[13] = "fr_Tipologia";
$fr_frase[14] = "fr_Le_date_sono_sbagliate";
$fr_frase[15] = "fr_La_tipologia_e_sbagliata";
$fr_frase[16] = "fr_Il_numero_di";
$fr_frase[17] = "fr_richiesto_e_sbagliato";
$fr_frase[18] = "fr_parola_La";
$fr_frase[19] = "fr_parola_settimana";
$fr_frase[20] = "fr_est";
$fr_frase[21] = "fr_piena";
$fr_frase[22] = "fr_Non_c_e_piu_disponibilita_nel_periodo_richiesto";
$fr_frase[23] = "fr_C_e_ancora_disponibilita";
$fr_frase[24] = "fr_nel_periodo_richiesto";
$fr_frase[25] = "fr_nei_periodi_richiesti";
$fr_frase[26] = "fr_per_le_tipologie_richieste";
$fr_frase[27] = "fr_Periodo_di";
$fr_frase[28] = "fr_parola_settimane";
$fr_frase[29] = "fr_tipologia";
$fr_frase[30] = "fr_Non_c_e_tariffa_per_questa_tipologia_ecc";
$fr_frase[31] = "fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo";
$fr_frase[32] = "fr_E_necessario_inserire_il_numero_di_persone_ecc";
$fr_frase[33] = "fr_Prezzo";
$fr_frase[34] = "fr_Totale";
$fr_frase[35] = "fr_Caparra";
$fr_frase[36] = "fr_compresi";
$fr_frase[37] = "fr_di";
$fr_frase[38] = "fr_Torna_indietro";
$fr_frase[39] = "fr_Nuovo_controllo";
$fr_frase[40] = "fr_Invia_la_richiesta_di_prenotazione";
$fr_frase[41] = "fr_Richiesta_di_prenotazione_inviata";
$fr_frase[42] = "fr_Non_e_stato_possibile_inviare_la_richiesta";
$fr_frase[43] = "fr_Scegliere_le_settimane_in_cui_applicare";
$fr_frase[44] = "fr_persone";
$fr_frase[45] = "fr_persona";
$fr_frase[46] = "fr_Continua";
$fr_frase[47] = "fr_per_ogni";
$fr_frase[48] = "fr_Si_deve_inserire_il_numero_delle_persone_per";
$fr_frase[49] = "fr_Errore_nei_servizi_opzionali_richiesti";
$fr_frase[50] = "fr_con_i_servizi_opzionali_selezionati";
$fr_frase[51] = "fr_supera_la_capienza_massima_della_tipologia_richiesta";
$fr_frase[52] = "fr_Quadro_indicativo_disponibilita";
$fr_frase[53] = "fr_Gennaio";
$fr_frase[54] = "fr_Febbraio";
$fr_frase[55] = "fr_Marzo";
$fr_frase[56] = "fr_Aprile";
$fr_frase[57] = "fr_Maggio";
$fr_frase[58] = "fr_Giugno";
$fr_frase[59] = "fr_Luglio";
$fr_frase[60] = "fr_Agosto";
$fr_frase[61] = "fr_Settembre";
$fr_frase[62] = "fr_Ottobre";
$fr_frase[63] = "fr_Novembre";
$fr_frase[64] = "fr_Dicembre";
$fr_frase[65] = "fr_Cognome";
$fr_frase[66] = "fr_Nome";
$fr_frase[67] = "fr_Email";
$fr_frase[68] = "fr_Commento";
$fr_frase[69] = "fr_Genere";
$fr_frase[70] = "fr_Data_di_nascita";
$fr_frase[71] = "fr_Documento";
$fr_frase[72] = "fr_Nazione";
$fr_frase[73] = "fr_Citta";
$fr_frase[74] = "fr_Regione";
$fr_frase[75] = "fr_Via";
$fr_frase[76] = "fr_Numero_civico";
$fr_frase[77] = "fr_Codice_postale";
$fr_frase[78] = "fr_Telefono";
$fr_frase[79] = "fr_Secondo_telefono";
$fr_frase[80] = "fr_Terzo_telefono";
$fr_frase[81] = "fr_Fax";
$fr_frase[82] = "fr_Orario_stimato_di_arrivo";
$fr_frase[83] = "fr_Accetto";
$fr_frase[84] = "fr_Metodo_di_pagamento_della_caparra";
$fr_frase[85] = "fr_campi_necessari";
$fr_frase[86] = "fr_asterisco_nero";
$fr_frase[87] = "fr_asterisco_rosso";
$fr_frase[88] = "fr_maschile";
$fr_frase[89] = "fr_femminile";
$fr_frase[90] = "fr_Prenota";
$fr_frase[91] = "fr_da";
$fr_frase[92] = "fr_OPPURE_linee";
$fr_frase[93] = "fr_Prenotazione_istantanea_con_PayPal";
$fr_frase[94] = "fr_Chiudi";
$fr_frase[95] = "fr_Richesta_prenotazione";
$fr_frase[96] = "fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc";
$fr_frase[97] = "fr_Copia_della_richiesta_e_stata_inviata_a";

$frase[0] = "in";
$frase[1] = "Non c'è più disponibilità";
$frase[2] = "Controlla la disponibilità";
$frase[3] = "dal";
$frase[4] = "al";
$frase[5] = "per la tipologia";
$frase[6] = "tariffa";
$frase[7] = "Numero di";
$frase[8] = "Aggiungi una nuova tipologia";
$frase[9] = "Elimina questa tipologia";
$frase[10] = "per";
$frase[11] = "Data di arrivo";
$frase[12] = "Data di partenza";
$frase[13] = "Tipologia";
$frase[14] = "Le date sono sbagliate";
$frase[15] = "La tipologia è sbagliata";
$frase[16] = "Il numero di";
$frase[17] = "richiesto è sbagliato";
$frase[18] = "$parola_La";
$frase[19] = "$parola_settimana";
$frase[20] = "è";
$frase[21] = "pien$lettera_a";
$frase[22] = "Non c'è più disponibilità nel periodo richiesto";
$frase[23] = "C'è ancora disponibilita";
$frase[24] = "nel periodo richiesto";
$frase[25] = "nei periodi richiesti";
$frase[26] = "per le tipologie richieste";
$frase[27] = "Periodo di";
$frase[28] = "$parola_settimane";
$frase[29] = "tipologia";
$frase[30] = "Non c'è ancora nessuna tariffa per la tipologia richiesta in questo periodo";
$frase[31] = "La tipologia richiesta è chiusa in questo periodo";
$frase[32] = "E' necessario inserire il numero di persone per questa tipologia";
$frase[33] = "Prezzo";
$frase[34] = "Totale";
$frase[35] = "Caparra";
$frase[36] = "compresi";
$frase[37] = "di";
$frase[38] = "Torna indietro";
$frase[39] = "Nuovo controllo";
$frase[40] = "Invia la richiesta di prenotazione";
$frase[41] = "Richiesta di prenotazione inviata";
$frase[42] = "Non è stato possibile inviare la richiesta";
$frase[43] = "Scegliere $parola_le $parola_settimane in cui applicare";
$frase[44] = "persone";
$frase[45] = "persona";
$frase[46] = "Continua";
$frase[47] = "per ogni";
$frase[48] = "Si deve inserire il numero delle persone per";
$frase[49] = "Errore nei servizi opzionali richiesti";
$frase[50] = "con i servizi opzionali selezionati";
$frase[51] = "supera la capienza massima della tipologia richiesta";
$frase[52] = "Quadro indicativo disponibilità";
$frase[53] = "Gennaio";
$frase[54] = "Febbraio";
$frase[55] = "Marzo";
$frase[56] = "Aprile";
$frase[57] = "Maggio";
$frase[58] = "Giugno";
$frase[59] = "Luglio";
$frase[60] = "Agosto";
$frase[61] = "Settembre";
$frase[62] = "Ottobre";
$frase[63] = "Novembre";
$frase[64] = "Dicembre";
$frase[65] = "Cognome";
$frase[66] = "Nome";
$frase[67] = "Email";
$frase[68] = "Commento";
$frase[69] = "Genere";
$frase[70] = "Data di nascita";
$frase[71] = "Documento";
$frase[72] = "Nazione";
$frase[73] = "Città";
$frase[74] = "Regione";
$frase[75] = "Via";
$frase[76] = "Numero civico";
$frase[77] = "Codice postale";
$frase[78] = "Telefono";
$frase[79] = "Secondo telefono";
$frase[80] = "Terzo telefono";
$frase[81] = "Fax";
$frase[82] = "Orario stimato di arrivo";
$frase[83] = "Accetto";
$frase[84] = "Metodo di pagamento della caparra";
$frase[85] = "<small>campi necessari</small>";
$frase[86] = "<small>*</small>";
$frase[87] = "<span style=\\\"color: red;\\\">*</span>";
$frase[88] = "M";
$frase[89] = "F";
$frase[90] = "Prenota";
$frase[91] = "da";
$frase[92] = "--- OPPURE ---";
$frase[93] = "Prenotazione istantanea con PayPal";
$frase[94] = "Chiudi";
$frase[95] = "Richesta prenotazione";
$frase[96] = "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile";
$frase[97] = "Copia della richiesta è stata inviata a";

$num_frasi = count($fr_frase);




?>

==> hoteldruid_2.2.0.orig.tar.gz: hoteldruid/includes/templates/frasi_mod_disp.php <==
<?php

##################################################################################
#    HOTELDRUID
#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    any later version accepted by Marco Maria Francesco De Santis, which
#    shall act as a proxy as defined in Section 14 of version 3 of the
#    license.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
##################################################################################




$fr_frase = "";
$frase = "";

$fr_frase[0] = "fr_in";
$fr_frase[1] = "fr_Non_c_e_piu_disponibilita";
$fr_frase[2] = "fr_Controlla_la_disponibilita";
$fr_frase[3] = "fr_dal";
$fr_frase[4] = "fr_al";
$fr_frase[5] = "fr_per_la_tipologia";
$fr_frase[6] = "fr_tariffa";
$fr_frase[7] = "fr_Numero_di";
$fr_frase[8] = "fr_Aggiungi_una_nuova_tipologia";
$fr_frase[9] = "fr_Elimina_questa_tipologia";
$fr_frase[10] = "fr_per";
$fr_frase[11] = "fr_Data_di_arrivo";
$fr_frase[12] = "fr_Data_di_partenza";
$fr_frase[13] = "fr_Tipologia";
$fr_frase[14] = "fr_Le_date_sono_sbagliate";
$fr_frase[15] = "fr_La_tipologia_e_sbagliata";
$fr_frase[16] = "fr_Il_numero_di";
$fr_frase[17] = "fr_richiesto_e_sbagliato";
$fr_frase[18] = "fr_parola_La";
$fr_frase[19] = "fr_parola_settimana";
$fr_frase[20] = "fr_est";
$fr_frase[21] = "fr_piena";
$fr_frase[22] = "fr_Non_c_e_piu_disponibilita_nel_periodo_richiesto";
$fr_frase[23] = "fr_C_e_ancora_disponibilita";
$fr_frase[24] = "fr_nel_periodo_richiesto";
$fr_frase[25] = "fr_nei_periodi_richiesti";
$fr_frase[26] = "fr_per_le_tipologie_richieste";
$fr_frase[27] = "fr_Periodo_di";
$fr_frase[28] = "fr_parola_settimane";
$fr_frase[29] = "fr_tipologia";
$fr_frase[30] = "fr_Non_c_e_tariffa_per_questa_tipologia_ecc";
$fr_frase[31] = "fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo";
$fr_frase[32] = "fr_E_necessario_inserire_il_numero_di_persone_ecc";
$fr_frase[33] = "fr_Prezzo";
$fr_frase[34] = "fr_Totale";
$fr_frase[35] = "fr_Caparra";
$fr_frase[36] = "fr_compresi";
$fr_frase[37] = "fr_di";
$fr_frase[38] = "fr_Torna_indietro";
$fr_frase[39] = "fr_Nuovo_controllo";
$fr_frase[40] = "fr_Invia_la_richiesta_di_prenotazione";
$fr_frase[41] = "fr_Richiesta_di_prenotazione_inviata";
$fr_frase[42] = "fr_Non_e_stato_possibile_inviare_la_richiesta";
$fr_frase[43] = "fr_Scegliere_le_settimane_in_cui_applicare";
$fr_frase[44] = "fr_persone";
$fr_frase[45] = "fr_persona";
$fr_frase[46] = "fr_Continua";
$fr_frase[47] = "fr_per_ogni";
$fr_frase[48] = "fr_Si_deve_inserire_il_numero_delle_persone_per";
$fr_frase[49] = "fr_Errore_nei_servizi_opzionali_richiesti";
$fr_frase[50] = "fr_con_i_servizi_opzionali_selezionati";
$fr_frase[51] = "fr_supera_la_capienza_massima_della_tipologia_richiesta";
$fr_frase[52] = "fr_Quadro_indicativo_disponibilita";
$fr_frase[53] = "fr_Gennaio";
$fr_frase[54] = "fr_Febbraio";
$fr_frase[55] = "fr_Marzo";
$fr_frase[56] = "fr_Aprile";
$fr_frase[57] = "fr_Maggio";
$fr_frase[58] = "fr_Giugno";
$fr_frase[59] = "fr_Luglio";
$fr_frase[60] = "fr_Agosto";
$fr_frase[61] = "fr_Settembre";
$fr_frase[62] = "fr_Ottobre";
$fr_frase[63] = "fr_Novembre";
$fr_frase[64] = "fr_Dicembre";
$fr_frase[65] = "fr_Cognome";
$fr_frase[66] = "fr_Nome";
$fr_frase[67] = "fr_Email";
$fr_frase[68] = "fr_Commento";
$fr_frase[69] = "fr_Genere";
$fr_frase[70] = "fr_Data_di_nascita";
$fr_frase[71] = "fr_Documento";
$fr_frase[72] = "fr_Nazione";
$fr_frase[73] = "fr_Citta";
$fr_frase[74] = "fr_Regione";
$fr_frase[75] = "fr_Via";
$fr_frase[76] = "fr_Numero_civico";
$fr_frase[77] = "fr_Codice_postale";
$fr_frase[78] = "fr_Telefono";
$fr_frase[79] = "fr_Secondo_telefono";
$fr_frase[80] = "fr_Terzo_telefono";
$fr_frase[81] = "fr_Fax";
$fr_frase[82] = "fr_Codice_fiscale";
$fr_frase[83] = "fr_Partita_iva";
$fr_frase[84] = "fr_Orario_stimato_di_arrivo";
$fr_frase[85] = "fr_Accetto";
$fr_frase[86] = "fr_Metodo_di_pagamento_della_caparra";
$fr_frase[87] = "fr_campi_necessari";
$fr_frase[88] = "fr_asterisco_nero";
$fr_frase[89] = "fr_asterisco_rosso";
$fr_frase[90] = "fr_maschile";
$fr_frase[91] = "fr_femminile";
$fr_frase[92] = "fr_Prenota";
$fr_frase[93] = "fr_da";
$fr_frase[94] = "fr_OPPURE_linee";
$fr_frase[95] = "fr_Prenotazione_istantanea_con_PayPal";
$fr_frase[96] = "fr_Chiudi";
$fr_frase[97] = "fr_Richesta_prenotazione";
$fr_frase[98] = "fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc";
$fr_frase[99] = "fr_Copia_della_richiesta_e_stata_inviata_a";
$fr_frase[100] = "fr_posizioni_vicine";
$fr_frase[101] = "fr_con_posizioni_vicine";


$frase[0] = "in";
$frase[1] = "Non c'è più disponibilità";
$frase[2] = "Controlla la disponibilità";
$frase[3] = "dal";
$frase[4] = "al";
$frase[5] = "per la tipologia";
$frase[6] = "tariffa";
$frase[7] = "Numero di";
$frase[8] = "Aggiungi una nuova tipologia";
$frase[9] = "Elimina questa tipologia";
$frase[10] = "per";
$frase[11] = "Data di arrivo";
$frase[12] = "Data di partenza";
$frase[13] = "Tipologia";
$frase[14] = "Le date sono sbagliate";
$frase[15] = "La tipologia è sbagliata";
$frase[16] = "Il numero di";
$frase[17] = "richiesto è sbagliato";
$frase[18] = "$parola_La";
$frase[19] = "$parola_settimana";
$frase[20] = "è";
$frase[21] = "pien$lettera_a";
$frase[22] = "Non c'è più disponibilità nel periodo richiesto";
$frase[23] = "C'è ancora disponibilità";
$frase[24] = "nel periodo richiesto";
$frase[25] = "nei periodi richiesti";
$frase[26] = "per le tipologie richieste";
$frase[27] = "Periodo di";
$frase[28] = "$parola_settimane";
$frase[29] = "tipologia";
$frase[30] = "Non c'è ancora nessuna tariffa per la tipologia richiesta in questo periodo";
$frase[31] = "La tipologia richiesta è chiusa in questo periodo";
$frase[32] = "E' necessario inserire il numero di persone per questa tipologia";
$frase[33] = "Prezzo";
$frase[34] = "Totale";
$frase[35] = "Caparra";
$frase[36] = "compresi";
$frase[37] = "di";
$frase[38] = "Torna indietro";
$frase[39] = "Nuovo controllo";
$frase[40] = "Invia la richiesta di prenotazione";
$frase[41] = "Richiesta di prenotazione inviata";
$frase[42] = "Non è stato possibile inviare la richiesta";
$frase[43] = "Scegliere $parola_le $parola_settimane in cui applicare";
$frase[44] = "persone";
$frase[45] = "persona";
$frase[46] = "Continua";
$frase[47] = "per ogni";
$frase[48] = "Si deve inserire il numero delle persone per";
$frase[49] = "Errore nei servizi opzionali richiesti";
$frase[50] = "con i servizi opzionali selezionati";
$frase[51] = "supera la capienza massima della tipologia richiesta";
$frase[52] = "Quadro indicativo disponibilità";
$frase[53] = "Gennaio";
$frase[54] = "Febbraio";
$frase[55] = "Marzo";
$frase[56] = "Aprile";
$frase[57] = "Maggio";
$frase[58] = "Giugno";
$frase[59] = "Luglio";
$frase[60] = "Agosto";
$frase[61] = "Settembre";
$frase[62] = "Ottobre";
$frase[63] = "Novembre";
$frase[64] = "Dicembre";
$frase[65] = "Cognome";
$frase[66] = "Nome";
$frase[67] = "Email";
$frase[68] = "Commento";
$frase[69] = "Genere";
$frase[70] = "Data di nascita";
$frase[71] = "Documento";
$frase[72] = "Nazione";
$frase[73] = "Città";
$frase[74] = "Regione";
$frase[75] = "Via";
$frase[76] = "Numero civico";
$frase[77] = "Codice postale";
$frase[78] = "Telefono";
$frase[79] = "Secondo telefono";
$frase[80] = "Terzo telefono";
$frase[81] = "Fax";
$frase[82] = "Codice fiscale";
$frase[83] = "Partita iva";
$frase[84] = "Orario stimato di arrivo";
$frase[85] = "Accetto";
$frase[86] = "Metodo di pagamento della caparra";
$frase[87] = "<small>campi necessari</small>";
$frase[88] = "<small>*</small>";
$frase[89] = "<span style=\\\"color: red;\\\">*</span>";
$frase[90] = "M";
$frase[91] = "F";
$frase[92] = "Prenota";
$frase[93] = "da";
$frase[94] = "--- OPPURE ---";
$frase[95] = "Prenotazione istantanea con PayPal";
$frase[96] = "Chiudi";
$frase[97] = "Richesta prenotazione";
$frase[98] = "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile";
$frase[99] = "Copia della richiesta è stata inviata a";
$frase[100] = "posizioni vicine";
$frase[101] = "con posizioni vicine";

$num_frasi = count($fr_frase);




?>
